/*
 * EasyBeans
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IDataSource.java 6280 2012-08-30 09:52:43Z albertil $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api.xml.struct;

import java.io.Serializable;

/**
 * Interface used for data-source elements used in Java EE components.
 * @author Loic Albertin
 */
public interface IDataSource extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "data-source";

    /**
     * JNDI name by which the data source name will be registered.
     */
    String getName();

    /**
     * JNDI name by which the data source name will be registered.
     *
     * @param name the given JNDI name
     */
    void setName(String name);

    /**
     * DataSource implementation class className.
     */
    String getClassName();

    /**
     * DataSource implementation class className.
     *
     * @param className the given DataSource implementation class name
     */
    void setClassName(String className);

    /**
     * Description of the data source.
     */
    String getDescription();

    /**
     * Description of the data source
     *
     * @param description the given description
     */
    void setDescription(String description);

    /**
     * A JDBC url. If the url property is specified along with other standard DataSource properties such as
     * serverName and
     * portNumber, the more specific properties will take precedence and the url will be ignored
     */
    String getUrl();

    /**
     * A JDBC url. If the url property is specified along with other standard DataSource properties such as
     * serverName and
     * portNumber, the more specific properties will take precedence and the url will be ignored
     *
     * @param url the given JDBC url
     */
    void setUrl(String url);

    /**
     * User name for connection authentications
     */
    String getUser();

    /**
     * User name for connection authentications
     *
     * @param user the given user name
     */
    void setUser(String user);

    /**
     * password for connection authentications
     */
    String getPassword();

    /**
     * password for connection authentications
     *
     * @param password the given password
     */
    void setPassword(String password);

    /**
     * Name of a database on a server
     */
    String getDatabaseName();

    /**
     * Name of a database on a server
     *
     * @param databaseName the given name of the database
     */
    void setDatabaseName(String databaseName);

    /**
     * Port number where a server is listening for requests
     */
    Integer getPortNumber();

    /**
     * Port number where a server is listening for requests
     *
     * @param portNumber the given port number
     */
    void setPortNumber(Integer portNumber);

    /**
     * Database server name
     */
    String getServerName();

    /**
     * Database server name
     *
     * @param serverName the given Database server name
     */
    void setServerName(String serverName);

    /**
     * Isolation level for connections.
     */
    Integer getIsolationLevel();

    /**
     * Isolation level for connections.
     *
     * @param isolationLevel the given isolation level
     */
    void setIsolationLevel(Integer isolationLevel);

    /**
     * Indicates whether a connection is transactional or not.
     */
    Boolean isTransactional();

    /**
     * Indicates whether a connection is transactional or not.
     *
     * @param transactional Indicates whether a connection is transactional or not.
     */
    void setTransactional(Boolean transactional);

    /**
     * Number of connections that should be created when a connection pool is initialized
     */
    Integer getInitialPoolSize();

    /**
     * Number of connections that should be created when a connection pool is initialized
     *
     * @param initialPoolSize the given initial connection pool size
     */
    void setInitialPoolSize(Integer initialPoolSize);

    /**
     * Maximum number of connections that should be concurrently allocated for a connection pool
     */
    Integer getMaxPoolSize();

    /**
     * Maximum number of connections that should be concurrently allocated for a connection pool
     *
     * @param maxPoolSize the given maximum connection pool size
     */
    void setMaxPoolSize(Integer maxPoolSize);

    /**
     * Minimum number of connections that should be allocated for a connection pool
     */
    Integer getMinPoolSize();

    /**
     * Minimum number of connections that should be allocated for a connection pool
     *
     * @param minPoolSize the given minimum connection pool size
     */
    void setMinPoolSize(Integer minPoolSize);

    /**
     * The number of seconds that a physical connection should remain unused in the pool before the connection is
     * closed for a
     * connection pool
     */
    Integer getMaxIdleTime();

    /**
     * The number of seconds that a physical connection should remain unused in the pool before the connection is
     * closed for a connection pool
     *
     * @param maxIdleTime the given maximum idle time
     */
    void setMaxIdleTime(Integer maxIdleTime);

    /**
     * The total number of statements that a connection pool should keep open. A value of 0 indicates that the
     * caching of
     * statements is disabled for a connection pool.
     */
    Integer getMaxStatements();

    /**
     * The total number of statements that a connection pool should keep open. A value of 0 indicates that the
     * caching of statements is disabled for a connection pool.
     *
     * @param maxStatements the given maximum statements caching
     */
    void setMaxStatements(Integer maxStatements);

    /**
     * Used to specify vendor specific properties and less commonly used DataSource properties.
     */
    String[] getProperties();

    /**
     * Used to specify vendor specific properties and less commonly used DataSource properties.
     *
     * @param properties the given properties
     */
    void setProperties(String[] properties);

    /**
     * The maximum time in seconds that this data source will wait while attempting to connect to a database. A value
     * of 0
     * specifies that the timeout is the default system timeout if there is one, otherwise it specifies that there is
     * no timeout
     */
    Integer getLoginTimeout();

    /**
     * The maximum time in seconds that this data source will wait while attempting to connect to a database. A value
     * of 0
     * specifies that the timeout is the default system timeout if there is one, otherwise it specifies that there is
     * no timeout
     *
     * @param loginTimeout the given login timeout
     */
    void setLoginTimeout(Integer loginTimeout);
}
