/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IHandlerChain.java 4672 2009-02-20 15:24:30Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import javax.xml.namespace.QName;

/**
 * The IHandlerChain represents a <code>handler-chain</code>.
 *
 * @author Guillaume Sauthier
 */
public interface IHandlerChain extends Serializable {

    /**
     * Name of the XML element.
     */
    static final String NAME = "handler-chain";

    /**
     * @return a QName representing a pattern for matching a service name.
     */
    QName getServiceNamePattern();

    /**
     * @return a QName representing a pattern for matching a port name.
     */
    QName getPortNamePattern();

    /**
     * @return a list of protocol bindings IDs
     */
    List<String> getProtocolBindings();

    /**
     * @return the list of <code>handler</code> composing this chain.
     */
    List<IHandler> getHandlers();
}
